#!/bin/bash
# 
# Install flash plugin - from website or from directory -
#   (is kept if configuration is saved!)
#
# GPL
#
# Author: Fabian Franz <knx-flash@fabian-franz.de>
#
# Spanish translation by Sergio Gonzlez, sergio.gonzalez@hispalinux.es

# Constants

VERSION="0.1-2";
FLASH_PATH= # unset flash path
FLASH_NAME="install_flash_player_6_linux.tar.gz"
FLASH_DIR="install_flash_player_6_linux"
FLASH_FILES="flashplayer.xpt libflashplayer.so"
FLASH_DL_PATH="http://macromedia.mplug.org/tarball/debian/install_flash_player_6_linux.tar.gz"
#FLASH_DL_PATH="http://freshmeat.net/redir/flashplugin/33881/url_tgz/install_flash_player_6_linux.tar.gz"
[ -z "$HOME" ] && HOME="/home/knoppix"
FLASH_EULA="http://www.macromedia.com/LANGUAGEshockwave/download/license/desktop/" # Where eula is located
INTERACTIVE="yes"

clean_exit(){
  [ -n "$TMPDIR" ] && rm -rf "$TMPDIR"
}

trap clean_exit EXIT

function setup_dialog()
{
  # Set up dialog
  XDIALOG_HIGH_DIALOG_COMPAT=1
  export XDIALOG_HIGH_DIALOG_COMPAT

  TMPDIR="/tmp/knx-flashplugin.$$"
  mkdir -p $TMPDIR
  TMP="$TMPDIR/dialog"

  DIALOG="dialog"
  [ -n "$DISPLAY" ] && [ -x /usr/bin/Xdialog ] && DIALOG="Xdialog"

  [ -f /etc/sysconfig/i18n ] && . /etc/sysconfig/i18n

  MAX=5 # number of steps

  case "$LANGUAGE" in
   de*)
     BT="Flashplugin-Installation"
     T1="Installation von Macromedia Flash (Schritt 0/$MAX)"
     ET="Installation fehlgeschlagen"
     ST="Installation erfolgreich"
     MESSAGE0="Dieses Skript installiert das Macromedia-Flashplugin aus dem Internet oder von einem Verzeichnis Ihrer Wahl.\n\nAutor: Fabian Franz <knx-flash@fabian-franz.de>"
     MESSAGE_EULA="Ich habe die Macromedia-EULA gelesen und akzeptiere Sie." 
     MESSAGE1="Soll das Flash-Plugin aus dem Internet heruntergeladen werden?"
     MESSAGE2="Bitte geben Sie das Verzeichnis an, wo $FLASH_NAME gefunden werden kann."
     MESSAGE3="PATH nicht gefunden. Das Skript wird beendet."
     MESSAGE4="Scanne nach neuen Plugins. (Konqueror)"
     MESSAGE5="Das Flash-Plugin wurde erfolgreich installiert."
     FLASH_EULA_LANG="de/" # check if its really supported
     ;;
   es)
     BT="Instalacin del plugin de Flash"
     T1="Instalacin de Macromedia Flash (Paso 0/$MAX)"
     ET="La instalacin ha fallado"
     ST="Instalacin completada"
     MESSAGE0="Este script instala el plugin flash de Macromedia desde Internet o desde un directorio de su eleccin.\n\nAutor: Fabian Franz <knx-flash@fabian-franz.de>"
     MESSAGE_EULA="He ledo la licencia EULA de Macromedia y la he aceptado."
     MESSAGE1="Se ha de bajar el plugin de flash desde Internet?"
     MESSAGE2="Por favor, teclea el nombre del directorio, donde se puede encontrar el archivo $FLASH_NAME."
     MESSAGE3="PATH no encontrada. El script terminar."
     MESSAGE4="Buscando nuevos plugins. (Konqueror)"
     MESSAGE5="El plugin de Flash se ha instalado correctamente."
     FLASH_EULA_LANG="es/" # check if its really supported
     ;;
   *)
     BT="Flashplugin-Installation"
     T1="Installation of Macromedia Flash (Step 0/$MAX)"
     ET="Installation failed"
     ST="Installation succeeded"
     MESSAGE0="This script installs the Macromedia-flashplugin from the internet or from a directory of your choice.\n\nAuthor: Fabian Franz <knx-flash@fabian-franz.de>"
     MESSAGE_EULA="I have read the Macromedia EULA and accept it." 
     MESSAGE1="Shall the flash plugin be downloaded from the internet?"
     MESSAGE2="Please insert the directory name, where $FLASH_NAME can be found."
     MESSAGE3="PATH not found. The script will be terminated."
     MESSAGE4="Scanning for new plugins. (Konqueror)"
     MESSAGE5="The Flash-Plugin was successfully installed."
     ;;
  esac  
  N=1; # Step 1
}

# Commandline parsing
while [ $# -ne 0 ];
do
  if [ "$1" = "-ni" ];
  then
    INTERACTIVE="no"
  fi
  
  if [ "$1" = "-i" ];
  then
    INTERACTIVE="yes"
  fi

  if [ "$1" = "--help" ];
  then
    echo "install_flashplugin - version $VERSION"
    echo "Usage: install_flashplugin <options from below>"
    echo "  -i             - Interactive Dialog mode (default)"
    echo "  -ni            - Non interactive install mode"
    echo "                   (you need to have read and accept the eula)"
    echo "  -l directory   - Where to find the flashplugin"
    echo "                   if not given it is downloaded from the internet"
    echo "  --help         - This help"
    exit 1
  fi

  if [ "$1" = "-l" ];
  then
    FLASH_PATH=$2
  fi

  shift # next parameter
done

[ "$INTERACTIVE" = "yes" ] && setup_dialog
 
if [ -n "$DIALOG" ]; then
  $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --msgbox "$MESSAGE0" 15 70
  N=$(($N+1))
 
 
  $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --yesno "$MESSAGE1" 15 70
  RC=$?
  N=$(($N+1))
  
  cd $TMPDIR
  if [ $RC -eq 1 ]; # give location
  then
    $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --inputbox "$MESSAGE2" 15 70 "$FLASH_PATH" 2>$TMP
    [ $? -eq 1 ] && exit 1 # cancel ?
    N=$(($N+1))
    FLASH_PATH=$(<$TMP)
    if [ -f $FLASH_PATH/$FLASH_NAME ]; then
      cp $FLASH_PATH/$FLASH_NAME /tmp
    else
      $DIALOG --backtitle "$BT" --title "$ET" --msgbox "${MESSAGE3/PATH/$FLASH_PATH/$FLASH_NAME}" 15 70 # error!
      exit 1
    fi
  else # dl it
    # dl eula
    FLASH_EULA_TMP="$TMPDIR/eula.txt"
    FLASH_EULA="${FLASH_EULA/LANGUAGE/$FLASH_EULA_LANG}" # check for localisations
    lynx -dump "$FLASH_EULA" > $FLASH_EULA_TMP
    if [ $? -eq 1 ]; 
    then
      $DIALOG --backtitle "$BT" --title "$ET" --msgbox "${MESSAGE3/PATH/$FLASH_EULA}" 15 70 # error!
      exit 1
    fi
    
    if [ "$DIALOG" = "dialog" ]; 
    then
      more $FLASH_EULA_TMP
      $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --defaultno --yesno "$MESSAGE_EULA" 15 70
    else
      XDIALOG_HIGH_DIALOG_COMPAT= $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --defaultno --textbox "$FLASH_EULA_TMP" 20 70
    fi
    [ $? -eq 1 ] && exit 1; # exit program if eula was not accepted
    N=$(($N+1))

    if [ $DIALOG = "dialog" ]; then
      wget $FLASH_DL_PATH
    else
      xterm -e wget $FLASH_DL_PATH
    fi
    N=$(($N+1))
  fi

  # Now we should have a /tmp/$FLASH_NAME

  if [ -f $TMPDIR/$FLASH_NAME ];
  then
    tar xzf $FLASH_NAME
    cd $FLASH_DIR
    mkdir -p $HOME/.netscape/plugins/
    mkdir -p $HOME/.mozilla/plugins/
    cp $FLASH_FILES $HOME/.netscape/plugins/
    cp $FLASH_FILES $HOME/.mozilla/plugins/
    RC=$?
    cd ..
    #cleanup
    rm -rf $FLASH_DIR
    rm -f $FLASH_NAME

    if [ $RC -eq 0 ]; 
    then
      # scan for new plugins
      ( nspluginscan 2>/dev/null; echo "100" ) | $DIALOG --backtitle "$BT" --title "${T1/0/$N}" --gauge "$MESSAGE4" 10 60
    else
      $DIALOG --backtitle "$BT" --title "$ET" --msgbox "${MESSAGE3/PATH/$FLASH_FILES}" 15 70 # error!
      exit 1
    fi
  else # /tmp/$FLASH_NAME not found
    $DIALOG --backtitle "$BT" --title "$ET" --msgbox "${MESSAGE3/PATH/$TMPDIR/$FLASH_NAME}" 15 70 # error!
    exit 1
  fi
  $DIALOG --backtitle "$BT" --title "$ST" --msgbox "$MESSAGE5" 10 60
else # non interactive
  cd /tmp
  if [ -n "$FLASH_PATH" ]; 
  then
    cp $FLASH_PATH/$FLASH_NAME /tmp
  else
    wget $FLASH_DL_PATH
  fi
  if [ -f /tmp/$FLASH_NAME ];
  then
    tar xzf $FLASH_NAME
    cd $FLASH_DIR
    mkdir -p $HOME/.netscape/plugins/
    mkdir -p $HOME/.mozilla/plugins/
    cp $FLASH_FILES $HOME/.netscape/plugins/
    cp $FLASH_FILES $HOME/.mozilla/plugins/
    cd ..
    #cleanup
    rm -rf $FLASH_DIR
    rm -f $FLASH_NAME

    # scan for new plugins
    nspluginscan
  else
    echo "Error accessing /tmp/$FLASH_NAME"
    exit 1
  fi
fi

exit 0 # Success!
